@@ -3,7 +3,7 @@ export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bi
 echo 'name: yesod-default
 version: 1.2.0
 id: yesod-default-1.2.0-5d724e6255914e391bee90b30a4cef13
-key: yesod_IadK8Mp1XTP6AsusJeQ0Xb
+key: yesod_5bJoiTvhFIQAYHKBSLRaoc
 license: MIT
 maintainer: Patrick Brisbin <pbrisbin@gmail.com>
 stability: Stable
@@ -21,10 +21,10 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-default-1.2.0
 library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-default-1.2.0
 data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-default-1.2.0
-hs-libraries: HSyesod-default-1.2.0-IadK8Mp1XTP6AsusJeQ0Xb
+hs-libraries: HSyesod-default-1.2.0-5bJoiTvhFIQAYHKBSLRaoc
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    yesod-core-1.4.20-0795e5dd1fccda51b978355252f3f0a8
+    yesod-core-1.4.20.2-b3dddaeebe1e00a8ca9ebbc062ef002b
 haddock-interfaces: /usr/share/doc/haskell-yesod-default/html/yesod-default.haddock
 haddock-html: /usr/share/doc/haskell-yesod-default/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
